function coef=frametf2coef(F,coef);
%FRAMETF2COEF  Convert coefficients from TF-plane format
%   Usage: cout=frametf2coef(F,cin);
%
%   FRAMETF2COEF(F,coef) convert frame coefficients from the
%   time-frequency plane layout into the common column format.
%
%   See also: newframe, framecoef2tf, framecoef2native
%
%   Url: http://ltfat.sourceforge.net/doc/frames/frametf2coef.php

% Copyright (C) 2005-2012 Peter L. Soendergaard.
% This file is part of LTFAT version 1.1.0
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
% 
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% 
% You should have received a copy of the GNU General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
  
if nargin<2
  error('%s: Too few input parameters.',upper(mfilename));
end;

if ~isstruct(F)
  error('%s: First agument must be a frame definition structure.',upper(mfilename));
end;

switch(F.type)
 case {'dgt','dgtreal','wmdct'}
  [M,N,W]=size(coef);
  coef=reshape(coef,[M*N,W]); 
 case {'wmdct','ufilterbank'}
  coef=framenative2coef(F,rect2wil(coef));
 case {'ufilterbank'}
  coef=permute(coef,[2,1,3]);
  [M,N,W]=size(coef);
  coef=reshape(coef,[M*N,W]); 
 otherwise
  error('%s: TF-plane layout not supported for this transform.',upper(mfilename));
end;

